@@ -11,13 +11,13 @@
 #define PANGOMM_MAJOR_VERSION 2
 
 /* Minor version number of pangomm. */
-#define PANGOMM_MINOR_VERSION 46
+#define PANGOMM_MINOR_VERSION 50
 
 /* Micro version number of pangomm. */
-#define PANGOMM_MICRO_VERSION 3
+#define PANGOMM_MICRO_VERSION 0
 
 /* Enable DLL-specific stuff only when not building a static library */
-#if !defined(__CYGWIN__) && (defined(__MINGW32__) || defined (_MSC_VER)) && !defined(PANGOMM_STATIC_LIB) && !defined (PANGOMM_USE_GENDEF)
+#if !defined(__CYGWIN__) && (defined(__MINGW32__) || defined (_MSC_VER)) && !defined(PANGOMM_STATIC_LIB)
 # define PANGOMM_DLL 1
 #endif
 
